import { __awaiter } from "tslib";
import 'zone.js/node';
import { ApplicationRef, InjectionToken, reflectComponentType, } from '@angular/core';
import { BEFORE_APP_SERIALIZED, provideServerRendering, renderApplication, ɵSERVER_CONTEXT, } from '@angular/platform-server';
import { bootstrapApplication } from '@angular/platform-browser';
const ANALOG_ASTRO_STATIC_PROPS = new InjectionToken('@analogjs/astro-angular: Static Props w/ Mirror Provider', {
    factory() {
        return { props: {}, mirror: {} };
    },
});
function check(Component, _props, _children) {
    return !!reflectComponentType(Component);
}
// Run beforeAppInitialized hook to set Input on the ComponentRef
// before the platform renders to string
const STATIC_PROPS_HOOK_PROVIDER = {
    provide: BEFORE_APP_SERIALIZED,
    useFactory: (appRef, { props, mirror, }) => {
        return () => {
            const compRef = appRef.components[0];
            if (compRef && props && mirror) {
                for (const [key, value] of Object.entries(props)) {
                    if (
                    // we double-check inputs on ComponentMirror
                    // because Astro might add additional props
                    // that aren't actually Input defined on the Component
                    mirror.inputs.some(({ templateName, propName }) => templateName === key || propName === key)) {
                        compRef.setInput(key, value);
                    }
                }
                compRef.changeDetectorRef.detectChanges();
            }
        };
    },
    deps: [ApplicationRef, ANALOG_ASTRO_STATIC_PROPS],
    multi: true,
};
function renderToStaticMarkup(Component, props, _children) {
    return __awaiter(this, void 0, void 0, function* () {
        const mirror = reflectComponentType(Component);
        const appId = (mirror === null || mirror === void 0 ? void 0 : mirror.selector) || Component.name.toString().toLowerCase();
        const document = `<${appId}></${appId}>`;
        const bootstrap = () => bootstrapApplication(Component, {
            providers: [
                {
                    provide: ANALOG_ASTRO_STATIC_PROPS,
                    useValue: { props, mirror },
                },
                STATIC_PROPS_HOOK_PROVIDER,
                provideServerRendering(),
                { provide: ɵSERVER_CONTEXT, useValue: 'analog' },
                ...(Component.renderProviders || []),
            ],
        });
        const html = yield renderApplication(bootstrap, {
            document,
        });
        return { html };
    });
}
export default {
    check,
    renderToStaticMarkup,
};
//# sourceMappingURL=server.js.map